RegisterBlock

Struct RegisterBlock 

#[repr(C)]
pub struct RegisterBlock { pub tasks_startecb: TASKS_STARTECB, pub tasks_stopecb: TASKS_STOPECB, pub events_endecb: EVENTS_ENDECB, pub events_errorecb: EVENTS_ERRORECB, pub intenset: INTENSET, pub intenclr: INTENCLR, pub ecbdataptr: ECBDATAPTR, pub power: POWER, /* private fields */ }
Register block

Fields

tasks_startecb: TASKS_STARTECB

0x00 - Start ECB block encrypt. If a crypto operation is running, this will not initiate a new encryption and the ERRORECB event will be triggered.

tasks_stopecb: TASKS_STOPECB

0x04 - Stop current ECB encryption. If a crypto operation is running, this will will trigger the ERRORECB event.

events_endecb: EVENTS_ENDECB

0x100 - ECB block encrypt complete.

events_errorecb: EVENTS_ERRORECB

0x104 - ECB block encrypt aborted due to a STOPECB task or due to an error.

intenset: INTENSET

0x304 - Interrupt enable set register.

intenclr: INTENCLR

0x308 - Interrupt enable clear register.

ecbdataptr: ECBDATAPTR

0x504 - ECB block encrypt memory pointer.

power: POWER

0xffc - Peripheral power control.