#[repr(C)]pub struct RegisterBlock {Show 16 fields
pub tasks_start: TASKS_START,
pub tasks_stop: TASKS_STOP,
pub tasks_clear: TASKS_CLEAR,
pub tasks_trigovrflw: TASKS_TRIGOVRFLW,
pub events_tick: EVENTS_TICK,
pub events_ovrflw: EVENTS_OVRFLW,
pub events_compare: [EVENTS_COMPARE; 4],
pub intenset: INTENSET,
pub intenclr: INTENCLR,
pub evten: EVTEN,
pub evtenset: EVTENSET,
pub evtenclr: EVTENCLR,
pub counter: COUNTER,
pub prescaler: PRESCALER,
pub cc: [CC; 4],
pub power: POWER,
/* private fields */
}Expand description
Register block
Fields
tasks_start: TASKS_START0x00 - Start RTC Counter.
tasks_stop: TASKS_STOP0x04 - Stop RTC Counter.
tasks_clear: TASKS_CLEAR0x08 - Clear RTC Counter.
tasks_trigovrflw: TASKS_TRIGOVRFLW0x0c - Set COUNTER to 0xFFFFFFF0.
events_tick: EVENTS_TICK0x100 - Event on COUNTER increment.
events_ovrflw: EVENTS_OVRFLW0x104 - Event on COUNTER overflow.
events_compare: [EVENTS_COMPARE; 4]0x140..0x150 - Compare event on CC[n] match.
intenset: INTENSET0x304 - Interrupt enable set register.
intenclr: INTENCLR0x308 - Interrupt enable clear register.
evten: EVTEN0x340 - Configures event enable routing to PPI for each RTC event.
evtenset: EVTENSET0x344 - Enable events routing to PPI. The reading of this register gives the value of EVTEN.
evtenclr: EVTENCLR0x348 - Disable events routing to PPI. The reading of this register gives the value of EVTEN.
counter: COUNTER0x504 - Current COUNTER value.
prescaler: PRESCALER0x508 - 12-bit prescaler for COUNTER frequency (32768/(PRESCALER+1)). Must be written when RTC is STOPed.
cc: [CC; 4]0x540..0x550 - Capture/compare registers.
power: POWER0xffc - Peripheral power control.