pub enum FRAMING_AW {
CLEAR = 1,
}Expand description
A valid stop bit is not detected on the serial data input after all bits in a character have been received.
Value on reset: 0
Variants
CLEAR = 1
1: Clear error on write.