pub struct W(/* private fields */);Expand description
Register ERRORSRC writer
Implementations
Sourceimpl W
impl W
Sourcepub fn overrun(&mut self) -> OVERRUN_W<'_, 0>
pub fn overrun(&mut self) -> OVERRUN_W<'_, 0>
Bit 0 - A start bit is received while the previous data still lies in RXD. (Data loss).
Sourcepub fn parity(&mut self) -> PARITY_W<'_, 1>
pub fn parity(&mut self) -> PARITY_W<'_, 1>
Bit 1 - A character with bad parity is received. Only checked if HW parity control is enabled.
Sourcepub fn framing(&mut self) -> FRAMING_W<'_, 2>
pub fn framing(&mut self) -> FRAMING_W<'_, 2>
Bit 2 - A valid stop bit is not detected on the serial data input after all bits in a character have been received.
Methods from Deref<Target = W<ERRORSRC_SPEC>>